Kometa Utils
==========================================================

.. image:: https://img.shields.io/github/v/release/Kometa-Team/Kometa-Utils?style=plastic
    :target: https://github.com/Kometa-Team/Kometa-Utils/releases
    :alt: GitHub release (latest by date)

.. image:: https://img.shields.io/pypi/v/kometa-utils?style=plastic
    :target: https://pypi.org/project/kometa-utils/
    :alt: PyPI

.. image:: https://img.shields.io/pypi/dm/kometa-utils.svg?style=plastic
    :target: https://pypi.org/project/kometa-utils/
    :alt: Downloads

.. image:: https://img.shields.io/github/commits-since/Kometa-Team/Kometa-Utils/latest?style=plastic
    :target: https://github.com/Kometa-Team/Kometa-Utils/commits/master
    :alt: GitHub commits since latest release (by date) for a branch

.. image:: https://img.shields.io/badge/-Sponsor_or_Donate-blueviolet?style=plastic
    :target: https://github.com/sponsors/meisnate12
    :alt: GitHub Sponsor

Overview
----------------------------------------------------------

Common Utility Methods and Modules used by Kometa and Kometa Partner Scripts


Installation & Documentation
----------------------------------------------------------

.. code-block:: python

    pip install kometautils
